@@ -17,7 +17,9 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
  *****************************************************************************/
 
+#define _GNU_SOURCE /* for getsid() */
 #include "mozplugger.h"
+#include <stdint.h>
 
 static Display *display;
 static int pipe_fd;
@@ -63,10 +65,10 @@ static void initSwallowMutex()
     swallowMutexTaken = 0;
 }
 
-unsigned long getHostId()
+uint32_t getHostId()
 {
     char hostName[128];
-    unsigned long id;
+    uint32 id;
     int i;
    
     memset(hostName, 0, sizeof(hostName));
@@ -79,20 +81,20 @@ unsigned long getHostId()
        effecting the swallow of victims is so infinitimisally small! */
 
     id = 0;
-    for(i=0; i < sizeof(hostName)/sizeof(unsigned long); i++)
+    for(i=0; i < sizeof(hostName)/sizeof(uint32_t); i++)
     {
-        id = ((id << 5) ^ (id >> 27)) ^ ((unsigned long *)hostName)[i];
+        id = ((id << 5) ^ (id >> 27)) ^ ((uint32_t *)hostName)[i];
     }
     return id;
 }
 
-static int getSwallowMutexOwner(unsigned long * hostId, unsigned long * pid)
+static int getSwallowMutexOwner(uint32_t * hostId, uint32_t * pid)
 {   
     unsigned long nitems;
     unsigned long bytes;      
     int fmt;
     Atom type;
-    unsigned char * property = 0;
+    unsigned char * property = NULL;
     int success = 0;
 
     /* Get hold of the Host & PID that current holds the semaphore for 
@@ -108,12 +110,12 @@ static int getSwallowMutexOwner(unsigned long * hostId, unsigned long * pid)
 	if((type != XA_INTEGER) || (fmt!=32) || (nitems!=2) || (bytes != 0))
         {
 	    fprintf(stderr, "XGetWindowProperty returned bad values " 
-                            "%d,%d,%d,%d\n", type, fmt, nitems, bytes);
+                            "%ld,%d,%ld,%ld\n", type, fmt, nitems, bytes);
         }
 	else
 	{
-            *hostId = ((unsigned long *)property)[0];
-            *pid = ((unsigned long *)property)[1];
+            *hostId = (uint32_t)((unsigned long *)property)[0];
+            *pid = (uint32_t)((unsigned long *)property)[1];
             success = 1;
         }
 	XFree(property);
@@ -121,9 +123,9 @@ static int getSwallowMutexOwner(unsigned long * hostId, unsigned long * pid)
     return success;
 }
 
-static void setSwallowMutexOwner(unsigned long hostId, unsigned long pid)
+static void setSwallowMutexOwner(uint32_t hostId, uint32_t pid)
 {
-    D("Setting swallow mutex owner, hostId = 0x%08X, pid=%ld\n", hostId, pid); 
+    D("Setting swallow mutex owner, hostId = 0x%08X, pid=%d\n", hostId, pid); 
     unsigned long temp[2] = {hostId, pid};
     XChangeProperty(display, wattr.root, swallowMutex,
                         XA_INTEGER, 32, PropModeReplace,
@@ -133,11 +135,11 @@ static void setSwallowMutexOwner(unsigned long hostId, unsigned long pid)
 static void takeSwallowMutex()
 {
     int countDown;
-    unsigned long ourPid = getpid();
-    unsigned long ourHostId = getHostId();
-    unsigned long otherPid;
-    unsigned long otherHostId;
-    unsigned long prevOtherPid;
+    uint32_t ourPid = (uint32_t)getpid();
+    uint32_t ourHostId = getHostId();
+    uint32_t otherPid;
+    uint32_t otherHostId;
+    uint32_t prevOtherPid = 0;
  
     D("Taking Swallow Mutex\n"); 
 
@@ -170,7 +172,7 @@ static void takeSwallowMutex()
                    if process exists. */
             	if( (getsid(otherPid) < 0 ) && (errno == ESRCH))
 	        {
-	    	    fprintf(stderr,"Strange other Pid(%ld) cannot be found\n", 
+	    	    fprintf(stderr,"Strange other Pid(%d) cannot be found\n", 
                                    otherPid);
                     break;    /* OK force early exit of inner while loop */
                 }
@@ -391,7 +393,8 @@ static Window winrecur(Window from, int depth, char *name, int (*cb)(Window))
 {
      Window root, parent;
      Window *children;
-     int e, num_children;
+     int e;
+     unsigned int num_children;
 
      D("Winrecur, checking window %x (depth=%d)\n",from,depth);
      
@@ -726,6 +729,7 @@ static void handle_app(int pid)
 
 int main(int argc, char **argv)
 {
+     unsigned long temp = 0;
      D("Helper started.....\n");
 
      if (argc < 2)
@@ -740,12 +744,14 @@ int main(int argc, char **argv)
 	    &flags,
 	    &repeats,
 	    &pipe_fd,
-	    (long unsigned int *) &windata.window,
+	    &temp,
 	    (int *)&windata.x,
 	    (int *)&windata.y,
 	    (int *)&windata.width,
 	    (int *)&windata.height);
 
+     windata.window = (void *)temp;
+
      command = argv[2];
      winname = getenv("winname");
      file = getenv("file");
