@@ -50,6 +50,7 @@ typedef struct data
      char *href;
      char *mms;
      char autostart;
+     char autostartNotSeen;
      int num_arguments;
      struct argument *args;
 } data_t;
@@ -168,6 +169,10 @@ static void run(NPP instance, const char *file)
      if ((THIS->flags & H_CONTROLS) && (THIS->mode == NP_FULL))
 	  THIS->flags &= ~(H_CONTROLS | H_SWALLOW | H_FILL);
 
+     // If No autostart seen and using controls, dont autostart by default
+     if ((THIS->flags & H_CONTROLS) && (THIS->autostartNotSeen))
+	  THIS->autostart = 0;
+
      snprintf(buffer, sizeof(buffer), "%d,%d,%d,%lu,%d,%d,%d,%d",
 	      THIS->flags,
 	      THIS->repeats,
@@ -990,6 +995,7 @@ NPError NPP_New(NPMIMEType pluginType,
      THIS->fd = -1;
      THIS->repeats = 1;
      THIS->autostart = 1;
+     THIS->autostartNotSeen = 1;
      THIS->mode = mode;
 
      if (!(THIS->mimetype = strdup(pluginType)))
@@ -1008,6 +1014,7 @@ NPError NPP_New(NPMIMEType pluginType,
 	  else if (!strcasecmp("autostart", argn[e]))
 	  {
 	       THIS->autostart = !!my_atoi(argv[e], 1, 0);
+	       THIS->autostartNotSeen = 0;
 	  }
 	  /* get the index of the src attribute */
 	  else if (!strcasecmp("src", argn[e]))
@@ -1310,14 +1317,18 @@ int32 NPP_Write(NPP instance,
 
 int32 NPP_WriteReady(NPP instance, NPStream *stream)
 {
-     D("WriteReady\n");
-
-     if (!instance)
-     {
-	  D("No instance\n");
-	  return 0;
-     }
-
-     D("Return MAXINT\n");
-     return MAXINT;
+    if (instance)
+    {
+	 /* Tell the browser that it can finish with the stream
+	    (actually we just wanted the name of the stream!)
+	    And not the stream data. */
+        NPN_DestroyStream(instance, stream, NPRES_DONE);
+        D("NPP_WriteReady - terminating the stream\n");
+    }
+    else 
+    {
+        D("NPP_WriteReady called with instance=0\n");
+    }
+    return 0;
 }
+
